==> apache-geode-1.4.0-src.zip: apache-geode-1.4.0-src/geode-core/src/main/java/org/apache/geode/internal/cache/persistence/PersistentStateListener.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache.persistence;

import org.apache.geode.distributed.internal.membership.InternalDistributedMember;

public interface PersistentStateListener {
  public static class PersistentStateAdapter implements PersistentStateListener {

    public void memberOffline(InternalDistributedMember member, PersistentMemberID persistentID) {}

    public void memberOnline(InternalDistributedMember member, PersistentMemberID persistentID) {}

    public void memberRemoved(PersistentMemberID persistentID, boolean revoked) {}
  }

  public void memberOnline(InternalDistributedMember member, PersistentMemberID persistentID);

  public void memberOffline(InternalDistributedMember member, PersistentMemberID persistentID);

  public void memberRemoved(PersistentMemberID persistentID, boolean revoked);
}

==> apache-geode-1.7.0-src.zip: apache-geode-1.7.0-src/geode-core/src/main/java/org/apache/geode/internal/cache/persistence/PersistentStateListener.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache.persistence;

import org.apache.geode.distributed.internal.membership.InternalDistributedMember;

public interface PersistentStateListener {
  class PersistentStateAdapter implements PersistentStateListener {

    public void memberOffline(InternalDistributedMember member, PersistentMemberID persistentID) {}

    public void memberOnline(InternalDistributedMember member, PersistentMemberID persistentID) {}

    public void memberRemoved(PersistentMemberID persistentID, boolean revoked) {}
  }

  void memberOnline(InternalDistributedMember member, PersistentMemberID persistentID);

  void memberOffline(InternalDistributedMember member, PersistentMemberID persistentID);

  void memberRemoved(PersistentMemberID persistentID, boolean revoked);
}
